@@ -16,7 +16,8 @@ def build(suffix):
         with open(ifn, 'w') as of:
             of.write(s)
 
-    check_call('debchange -m -D unstable --force-distribution -v $(python setup.py --version)-r$(hg tip --template "{rev}")+$(date +%s) "Automatic build"', shell=True)
+    check_call('debchange -m -D unstable --force-distribution -v $(python setup.py --version)+$(date +%s) "Automatic build"', \
+        shell=True)
     check_call('debuild -us -uc -b', shell=True)
 
 def clean(suffix):
