@@ -1,8 +1,9 @@
+from urlparse import urljoin
+
 from scrapy import log
 from scrapy.http import HtmlResponse
-from scrapy.utils.url import urljoin_rfc
 from scrapy.utils.response import get_meta_refresh
-from scrapy.exceptions import IgnoreRequest
+from scrapy.exceptions import IgnoreRequest, NotConfigured
 from scrapy.conf import settings
 
 
@@ -10,6 +11,8 @@ class RedirectMiddleware(object):
     """Handle redirection of requests based on response status and meta-refresh html tag"""
 
     def __init__(self):
+        if not settings.getbool('REDIRECT_ENABLED'):
+            raise NotConfigured
         self.max_metarefresh_delay = settings.getint('REDIRECT_MAX_METAREFRESH_DELAY')
         self.max_redirect_times = settings.getint('REDIRECT_MAX_TIMES')
         self.priority_adjust = settings.getint('REDIRECT_PRIORITY_ADJUST')
@@ -19,19 +22,19 @@ class RedirectMiddleware(object):
             return response
         if request.method.upper() == 'HEAD':
             if response.status in [301, 302, 303, 307] and 'Location' in response.headers:
-                redirected_url = urljoin_rfc(request.url, response.headers['location'])
+                redirected_url = urljoin(request.url, response.headers['location'])
                 redirected = request.replace(url=redirected_url)
                 return self._redirect(redirected, request, spider, response.status)
             else:
                 return response
 
         if response.status in [302, 303] and 'Location' in response.headers:
-            redirected_url = urljoin_rfc(request.url, response.headers['location'])
+            redirected_url = urljoin(request.url, response.headers['location'])
             redirected = self._redirect_request_using_get(request, redirected_url)
             return self._redirect(redirected, request, spider, response.status)
 
         if response.status in [301, 307] and 'Location' in response.headers:
-            redirected_url = urljoin_rfc(request.url, response.headers['location'])
+            redirected_url = urljoin(request.url, response.headers['location'])
             redirected = request.replace(url=redirected_url)
             return self._redirect(redirected, request, spider, response.status)
 
