@@ -11,24 +11,19 @@ class DownloaderStats(object):
             raise NotConfigured
 
     def process_request(self, request, spider):
-        stats.inc_value('downloader/request_count')
         stats.inc_value('downloader/request_count', spider=spider)
         stats.inc_value('downloader/request_method_count/%s' % request.method, spider=spider)
         reqlen = len(request_httprepr(request))
         stats.inc_value('downloader/request_bytes', reqlen, spider=spider)
-        stats.inc_value('downloader/request_bytes', reqlen)
 
     def process_response(self, request, response, spider):
-        stats.inc_value('downloader/response_count')
         stats.inc_value('downloader/response_count', spider=spider)
         stats.inc_value('downloader/response_status_count/%s' % response.status, spider=spider)
         reslen = len(response_httprepr(response))
         stats.inc_value('downloader/response_bytes', reslen, spider=spider)
-        stats.inc_value('downloader/response_bytes', reslen)
         return response
 
     def process_exception(self, request, exception, spider):
         ex_class = "%s.%s" % (exception.__class__.__module__, exception.__class__.__name__)
-        stats.inc_value('downloader/exception_count')
         stats.inc_value('downloader/exception_count', spider=spider)
         stats.inc_value('downloader/exception_type_count/%s' % ex_class, spider=spider)
