@@ -1,5 +1,6 @@
 from scrapy.contrib.exporter import JsonLinesItemExporter
+from scrapy.exceptions import ScrapyDeprecationWarning
 
 import warnings
 warnings.warn("Module `scrapy.contrib.exporter.jsonlines` is deprecated - use `scrapy.contrib.exporter` instead",
-    DeprecationWarning, stacklevel=2)
+    ScrapyDeprecationWarning, stacklevel=2)
