@@ -1,7 +1,7 @@
 import re
+from urlparse import urljoin
 
-from scrapy.utils.url import urljoin_rfc
-from scrapy.utils.markup import remove_tags, remove_entities, replace_escape_chars
+from w3lib.html import remove_tags, remove_entities, replace_escape_chars
 
 from scrapy.link import Link
 from .sgml import SgmlLinkExtractor
@@ -17,10 +17,11 @@ def clean_link(link_text):
 class RegexLinkExtractor(SgmlLinkExtractor):
     """High performant link extractor"""
 
-    def _extract_links(self, response_text, response_url, response_encoding):
-        base_url = urljoin_rfc(response_url, self.base_url) if self.base_url else response_url
+    def _extract_links(self, response_text, response_url, response_encoding, base_url=None):
+        if base_url is None:
+            base_url = urljoin(response_url, self.base_url) if self.base_url else response_url
 
-        clean_url = lambda u: urljoin_rfc(base_url, remove_entities(clean_link(u.decode(response_encoding))))
+        clean_url = lambda u: urljoin(base_url, remove_entities(clean_link(u.decode(response_encoding))))
         clean_text = lambda t: replace_escape_chars(remove_tags(t.decode(response_encoding))).strip()
 
         links_text = linkre.findall(response_text)
