@@ -10,11 +10,11 @@ import time
 import hashlib
 import urlparse
 import rfc822
-import Image
 from cStringIO import StringIO
 from collections import defaultdict
 
 from twisted.internet import defer, threads
+from PIL import Image
 
 from scrapy.xlib.pydispatch import dispatcher
 from scrapy import log
@@ -249,13 +249,13 @@ class ImagesPipeline(MediaPipeline):
         return dfd
 
     def image_downloaded(self, response, request, info):
-        first_buf = None
+        checksum = None
         for key, image, buf in self.get_images(response, request, info):
+            if checksum is None:
+                buf.seek(0)
+                checksum = md5sum(buf)
             self.store.persist_image(key, image, buf, info)
-            if first_buf is None:
-                first_buf = buf
-        first_buf.seek(0)
-        return md5sum(first_buf)
+        return checksum
 
     def get_images(self, response, request, info):
         key = self.image_key(request.url)
