@@ -6,10 +6,11 @@ Use STATSMAILER_RCPTS setting to enable and give the recipient mail address
 
 from scrapy.xlib.pydispatch import dispatcher
 
-from scrapy.stats import stats, signals
+from scrapy.stats import stats
+from scrapy import signals
 from scrapy.mail import MailSender
 from scrapy.conf import settings
-from scrapy.core.exceptions import NotConfigured
+from scrapy.exceptions import NotConfigured
 
 class StatsMailer(object):
 
@@ -23,6 +24,6 @@ class StatsMailer(object):
         mail = MailSender()
         body = "Global stats\n\n"
         body += "\n".join("%-50s : %s" % i for i in stats.get_stats().items())
-        body += "\n\n%s stats\n\n" % spider.domain_name
+        body += "\n\n%s stats\n\n" % spider.name
         body += "\n".join("%-50s : %s" % i for i in spider_stats.items())
-        mail.send(self.recipients, "Scrapy stats for: %s" % spider.domain_name, body)
+        mail.send(self.recipients, "Scrapy stats for: %s" % spider.name, body)
