@@ -5,6 +5,5 @@ class StatsResource(JsonRpcResource):
 
     ws_name = 'stats'
 
-    def __init__(self, _stats=stats):
-        JsonRpcResource.__init__(self)
-        self._target = _stats
+    def __init__(self, crawler):
+        JsonRpcResource.__init__(self, crawler, stats)
