@@ -1,13 +1,14 @@
+from time import time
 from urlparse import urlparse, urlunparse, urldefrag
 
 from twisted.python import failure
-from twisted.web.client import PartialDownloadError, HTTPClientFactory
+from twisted.web.client import HTTPClientFactory
 from twisted.web.http import HTTPClient
 from twisted.internet import defer
 
 from scrapy.http import Headers
 from scrapy.utils.httpobj import urlparse_cached
-from scrapy.core.downloader.responsetypes import responsetypes
+from scrapy.responsetypes import responsetypes
 
 
 def _parsed_url_args(parsed):
@@ -64,9 +65,6 @@ class ScrapyHTTPPageGetter(HTTPClient):
     def handleResponse(self, response):
         if self.factory.method.upper() == 'HEAD':
             self.factory.page('')
-        elif self.length != None and self.length != 0:
-            self.factory.noPage(failure.Failure(
-                PartialDownloadError(self.factory.status, None, response)))
         else:
             self.factory.page(response)
         self.transport.loseConnection()
@@ -97,7 +95,16 @@ class ScrapyHTTPClientFactory(HTTPClientFactory):
         self.headers = Headers(request.headers)
         self.response_headers = None
         self.timeout = request.meta.get('download_timeout') or timeout
-        self.deferred = defer.Deferred().addCallback(self._build_response)
+        self.start_time = time()
+        self.deferred = defer.Deferred().addCallback(self._build_response, request)
+
+        # Fixes Twisted 11.1.0+ support as HTTPClientFactory is expected
+        # to have _disconnectedDeferred. See Twisted r32329.
+        # As Scrapy implements it's own logic to handle redirects is not
+        # needed to add the callback _waitForDisconnect.
+        # Specifically this avoids the AttributeError exception when
+        # clientConnectionFailed method is called.
+        self._disconnectedDeferred = defer.Deferred()
 
         self._set_connection_attributes(request)
 
@@ -110,7 +117,8 @@ class ScrapyHTTPClientFactory(HTTPClientFactory):
             # just in case a broken http/1.1 decides to keep connection alive
             self.headers.setdefault("Connection", "close")
 
-    def _build_response(self, body):
+    def _build_response(self, body, request):
+        request.meta['download_latency'] = self.headers_time-self.start_time
         status = int(self.status)
         headers = Headers(self.response_headers)
         respcls = responsetypes.from_args(headers=headers, url=self.url)
@@ -125,4 +133,5 @@ class ScrapyHTTPClientFactory(HTTPClientFactory):
             self.path = self.url
 
     def gotHeaders(self, headers):
+        self.headers_time = time()
         self.response_headers = headers
