@@ -13,9 +13,6 @@ from scrapy.http.common import deprecated_setter
 
 class Response(object_ref):
 
-    __slots__ = ['_url', 'headers', 'status', '_body', 'request', \
-        'flags', '__weakref__']
-
     def __init__(self, url, status=200, headers=None, body='', flags=None, request=None):
         self.headers = Headers(headers or {})
         self.status = int(status)
@@ -61,14 +58,11 @@ class Response(object_ref):
 
     body = property(_get_body, deprecated_setter(_set_body, 'body'))
 
-    def __repr__(self):
-        attrs = ['url', 'status', 'body', 'headers', 'request', 'flags']
-        args = ", ".join(["%s=%r" % (a, getattr(self, a)) for a in attrs])
-        return "%s(%s)" % (self.__class__.__name__, args)
-
     def __str__(self):
         return "<%d %s>" % (self.status, self.url)
 
+    __repr__ = __str__
+
     def copy(self):
         """Return a copy of this Response"""
         return self.replace()
