@@ -18,7 +18,7 @@ class HtmlResponse(TextResponse):
     _content_re   = _template % ('content', r'(?P<mime>[^;]+);\s*charset=(?P<charset>[\w-]+)')
     _content2_re   = _template % ('charset', r'(?P<charset>[\w-]+)')
 
-    METATAG_RE  = re.compile(r'<meta\s+%s\s+%s' % (_httpequiv_re, _content_re), re.I)
+    METATAG_RE  = re.compile(r'<meta(?:\s+(?:%s|%s)){2}' % (_httpequiv_re, _content_re), re.I)
     METATAG2_RE  = re.compile(r'<meta\s+%s' % _content2_re, re.I)
 
     @memoizemethod_noargs
