@@ -7,7 +7,7 @@ See documentation in docs/topics/request-response.rst
 
 import re
 import codecs
-from scrapy.xlib.BeautifulSoup import UnicodeDammit
+from scrapy.http.response.dammit import UnicodeDammit
 from scrapy.http.response import Response
 from scrapy.utils.python import memoizemethod_noargs
 from scrapy.utils.encoding import encoding_exists, resolve_encoding
@@ -24,8 +24,6 @@ class TextResponse(Response):
     _DEFAULT_ENCODING = settings['DEFAULT_RESPONSE_ENCODING']
     _ENCODING_RE = re.compile(r'charset=([\w-]+)', re.I)
 
-    __slots__ = ['_encoding', '_cached_benc', '_cached_ubody']
-
     def __init__(self, *args, **kwargs):
         self._encoding = kwargs.pop('encoding', None)
         self._cached_benc = None
