@@ -5,7 +5,7 @@ spiders
 
 from zope.interface import implements
 
-from scrapy import log, signals
+from scrapy import signals
 from scrapy.interfaces import ISpiderManager
 from scrapy.utils.misc import walk_modules
 from scrapy.utils.spider import iter_spider_classes
@@ -32,8 +32,16 @@ class SpiderManager(object):
     def from_settings(cls, settings):
         return cls(settings.getlist('SPIDER_MODULES'))
 
+    @classmethod
+    def from_crawler(cls, crawler):
+        return cls.from_settings(crawler.settings)
+
     def create(self, spider_name, **spider_kwargs):
-        return self._spiders[spider_name](**spider_kwargs)
+        try:
+            spcls = self._spiders[spider_name]
+        except KeyError:
+            raise KeyError("Spider not found: %s" % spider_name)
+        return spcls(**spider_kwargs)
 
     def find_by_request(self, request):
         return [name for name, cls in self._spiders.iteritems()
