@@ -51,6 +51,13 @@ class LinkExtractorTestCase(unittest.TestCase):
         self.assertEqual(lx.extract_links(response),
                          [Link(url='https://noschemedomain.com/path/to/item/12.html', text='Item 12')])
 
+    def test_link_text_wrong_encoding(self):
+        html = """<body><p><a href="item/12.html">Wrong: \xed</a></p></body></html>"""
+        response = HtmlResponse("http://www.example.com", body=html, encoding='utf-8')
+        lx = BaseSgmlLinkExtractor()
+        self.assertEqual(lx.extract_links(response),
+             [Link(url='http://www.example.com/item/12.html', text=u'Wrong: \ufffd')])
+
     def test_extraction_encoding(self):
         body = get_testdata('link_extractor', 'linkextractor_noenc.html')
         response_utf8 = HtmlResponse(url='http://example.com/utf8', body=body, headers={'Content-Type': ['text/html; charset=utf-8']})
@@ -128,10 +135,6 @@ class SgmlLinkExtractorTestCase(unittest.TestCase):
         self.assertEqual([link for link in lx.extract_links(self.response)],
             [ Link(url='http://www.google.com/something', text=u'') ])
 
-        lx = SgmlLinkExtractor(tags=('img', ), attrs=('src', ))
-        self.assertEqual([link for link in lx.extract_links(self.response)],
-            [ Link(url='http://example.com/sample2.jpg', text=u'') ])
-
     def test_extraction_using_single_values(self):
         '''Test the extractor's behaviour among different situations'''
 
@@ -204,6 +207,13 @@ class SgmlLinkExtractorTestCase(unittest.TestCase):
         self.assertEqual(lx.extract_links(response),
                          [Link(url='http://example.org/about.html', text=u'About us\xa3')])
 
+    def test_deny_extensions(self):
+        html = """<a href="page.html">asd</a> and <a href="photo.jpg">"""
+        response = HtmlResponse("http://example.org/", body=html)
+        lx = SgmlLinkExtractor()
+        self.assertEqual(lx.extract_links(response),
+            [Link(url='http://example.org/page.html', text=u'asd')])
+
     def test_process_value(self):
         """Test restrict_xpaths with encodings"""
         html = """
