@@ -8,14 +8,13 @@ from twisted.web import server, static, util, resource
 from twisted.web.test.test_webclient import ForeverTakingResource, \
         NoLengthResource, HostHeaderResource, \
         PayloadResource, BrokenDownloadResource
+from w3lib.url import path_to_file_uri
 
-from scrapy.core.downloader.webclient import PartialDownloadError
 from scrapy.core.downloader.handlers.file import FileDownloadHandler
 from scrapy.core.downloader.handlers.http import HttpDownloadHandler
 from scrapy.core.downloader.handlers.s3 import S3DownloadHandler
 from scrapy.spider import BaseSpider
 from scrapy.http import Request
-from scrapy.utils.url import path_to_file_uri
 from scrapy import optional_features
 
 
@@ -131,11 +130,6 @@ class HttpTestCase(unittest.TestCase):
         d.addCallback(self.assertEquals, body)
         return d
 
-    def test_broken_download(self):
-        request = Request(self.getURL('broken'))
-        d = self.download_request(request, BaseSpider('foo'))
-        return self.assertFailure(d, PartialDownloadError)
-
 
 class UriResource(resource.Resource):
     """Return the full uri that was requested"""
