@@ -108,8 +108,12 @@ class RequestTest(unittest.TestCase):
         self.assertEqual(r4.body, "Price: \xa3100")
 
     def test_ajax_url(self):
+        # ascii url
         r = self.request_class(url="http://www.example.com/ajax.html#!key=value")
         self.assertEqual(r.url, "http://www.example.com/ajax.html?_escaped_fragment_=key=value")
+        # unicode url
+        r = self.request_class(url=u"http://www.example.com/ajax.html#!key=value")
+        self.assertEqual(r.url, "http://www.example.com/ajax.html?_escaped_fragment_=key=value")
 
     def test_copy(self):
         """Test Request copy"""
