@@ -5,12 +5,13 @@ scrapy.http.Request objects
 
 import hashlib
 import weakref
-from base64 import urlsafe_b64encode
 from urlparse import urlunparse
 
+from twisted.internet.defer import Deferred
+from w3lib.http import basic_auth_header
+
 from scrapy.utils.url import canonicalize_url
 from scrapy.utils.httpobj import urlparse_cached
-from scrapy.utils.http import basic_auth_header
 
 
 _fingerprint_cache = weakref.WeakKeyDictionary()
@@ -64,13 +65,6 @@ def request_authenticate(request, username, password):
     """
     request.headers['Authorization'] = basic_auth_header(username, password)
 
-def request_info(request):
-    """Return a short string with request info including method, url and
-    fingeprint. Mainly used for debugging
-    """
-    fp = request_fingerprint(request)
-    return "<Request: %s %s (%s..)>" % (request.method, request.url, fp[:8])
-
 def request_httprepr(request):
     """Return the raw HTTP representation (as string) of the given request.
     This is provided only for reference since it's not the actual stream of
@@ -86,3 +80,16 @@ def request_httprepr(request):
     s += "\r\n"
     s += request.body
     return s
+
+def request_deferred(request):
+    """Wrap a request inside a Deferred.
+
+    This returns a Deferred whose first pair of callbacks are the request
+    callback and errback. The Deferred also triggers when the request
+    callback/errback is executed (ie. when the request is downloaded)
+    """
+    d = Deferred()
+    if request.callback:
+        d.addCallbacks(request.callback, request.errback)
+    request.callback, request.errback = d.callback, d.errback
+    return d
