@@ -11,10 +11,8 @@ import tempfile
 
 from twisted.web import http
 from twisted.web.http import RESPONSES
+from w3lib import html
 
-from scrapy.utils.markup import remove_entities, remove_comments
-from scrapy.utils.url import safe_url_string, urljoin_rfc
-from scrapy.xlib.BeautifulSoup import BeautifulSoup
 from scrapy.http import Response, HtmlResponse
 
 def body_or_str(obj, unicode=True):
@@ -27,47 +25,28 @@ def body_or_str(obj, unicode=True):
     else:
         return obj if unicode else obj.encode('utf-8')
 
-BASEURL_RE = re.compile(ur'<base\s+href\s*=\s*[\"\']\s*([^\"\'\s]+)\s*[\"\']', re.I)
 _baseurl_cache = weakref.WeakKeyDictionary()
 def get_base_url(response):
-    """ Return the base url of the given response used to resolve relative links. """
+    """Return the base url of the given response, joined with the response url"""
     if response not in _baseurl_cache:
-        match = BASEURL_RE.search(response.body_as_unicode()[0:4096])
-        _baseurl_cache[response] = urljoin_rfc(response.url, match.group(1)) if match else response.url
+        text = response.body_as_unicode()[0:4096]
+        _baseurl_cache[response] = html.get_base_url(text, response.url, \
+            response.encoding)
     return _baseurl_cache[response]
 
-META_REFRESH_RE = re.compile(ur'<meta[^>]*http-equiv[^>]*refresh[^>]*content\s*=\s*(?P<quote>["\'])(?P<int>(\d*\.)?\d+)\s*;\s*url=(?P<url>.*?)(?P=quote)', \
-    re.DOTALL | re.IGNORECASE)
+_noscript_re = re.compile(u'<noscript>.*?</noscript>', re.IGNORECASE | re.DOTALL)
+_script_re = re.compile(u'<script.*?>.*?</script>', re.IGNORECASE | re.DOTALL)
 _metaref_cache = weakref.WeakKeyDictionary()
 def get_meta_refresh(response):
-    """Parse the http-equiv parameter of the HTML meta element from the given
-    response and return a tuple (interval, url) where interval is an integer
-    containing the delay in seconds (or zero if not present) and url is a
-    string with the absolute url to redirect.
-
-    If no meta redirect is found, (None, None) is returned.
-    """
+    """Parse the http-equiv refrsh parameter from the given response"""
     if response not in _metaref_cache:
-        body_chunk = remove_comments(remove_entities(response.body_as_unicode()[0:4096]))
-        match = META_REFRESH_RE.search(body_chunk)
-        if match:
-            interval = float(match.group('int'))
-            url = safe_url_string(match.group('url').strip(' "\''))
-            url = urljoin_rfc(response.url, url)
-            _metaref_cache[response] = (interval, url)
-        else:
-            _metaref_cache[response] = (None, None)
-        #_metaref_cache[response] = match.groups() if match else (None, None)
+        text = response.body_as_unicode()[0:4096]
+        text = _noscript_re.sub(u'', text)
+        text = _script_re.sub(u'', text)
+        _metaref_cache[response] = html.get_meta_refresh(text, response.url, \
+            response.encoding)
     return _metaref_cache[response]
 
-_beautifulsoup_cache = weakref.WeakKeyDictionary()
-def get_cached_beautifulsoup(response):
-    """Return BeautifulSoup object of the given response, with caching
-    support"""
-    if response not in _beautifulsoup_cache:
-        _beautifulsoup_cache[response] = BeautifulSoup(response.body)
-    return _beautifulsoup_cache[response]
-
 def response_status_message(status):
     """Return status code plus status text descriptive message
 
